@@ -160,7 +160,7 @@ getPlaylist <- function(opts = antaresRead::simOptions()) {
 #'  * `setPlaylist` does not return anything. It is  used to modify the input of an Antares study.
 #'
 #' @importFrom assertthat assert_that
-#' @importFrom antaresRead simOptions
+#' @importFrom antaresRead simOptions readIni
 #' @export
 #'
 #' @rdname playlist
@@ -171,9 +171,8 @@ setPlaylist <- function(playlist,
   api_study <- is_api_study(opts)
   
   version_study <- substr(opts$antaresVersion, 1, 1)
-  version_study <- as.numeric(version_study)
   
-  if (version_study < 8 & !is.null(weights)) {
+  if (as.numeric(version_study) < 8 & !is.null(weights)) {
     stop("weights can be use only for antares > V8, please convert your studie before")
   }
   
@@ -192,9 +191,9 @@ setPlaylist <- function(playlist,
   playlist <- sort(playlist)
   playlist <- unique(playlist)
   
-  
   # read general data parameters
   generaldata <- readIni("settings/generaldata", opts = opts)
+  existing_playlist_weight <- "playlist_year_weight" %in% names(generaldata$playlist)
   
   # if all mc_years must be simulated, desactive playlist
   if (length(playlist) == length(mc_years)) {
@@ -208,41 +207,27 @@ setPlaylist <- function(playlist,
   } else { # otherwise, set the playlist
     # update line to enable the playlist
     generaldata$general$`user-playlist` <- TRUE
-    
     # delete lines with current playlist
     generaldata$playlist <- NULL
     
     # create new playlist (+ patch double to integer)
     new_playlist <- setNames(as.list(sort(as.integer(playlist - 1))), rep("playlist_year +", length(playlist)))
-    if (api_study){
-      
+    playlist_weights <- .format_playlist_weights(weights = weights, api_mode = api_study)
+    
+    if (api_study) {
       new_playlist$sep <- ", "
       new_playlist <- list("playlist_year +" = paste0("[", do.call(paste, new_playlist), "]"))
-      
-      couple_value <- paste(weights$mcYears - 1, weights$weights, sep = ",")
-      element_list <- paste("\'", couple_value, "\'", 
-                            collapse  = ",", sep = "")
-      element_list <- paste("[", element_list, "]", sep = "")
-      new_playlist$playlist_year_weight <- element_list
+      if (existing_playlist_weight & is.null(playlist_weights)) {
+        weights <- data.table("mcYears" = playlist, "weights" = rep(1, length(playlist))) # 1 is the default weight
+        playlist_weights <- .format_playlist_weights(weights = weights, api_mode = TRUE) 
       }
-    else if (!is.null(weights)) {
-      
-      new_playlist <- c(
-        new_playlist,
-        setNames(apply(
-          X = weights,
-          MARGIN = 1,
-          FUN = function(X) {
-            paste0(
-              X[1] - 1,
-              ",",
-              format(round(X[2], 6), nsmall = 6)
-            )
-          }
-        ), rep("playlist_year_weight", length(weights$weights)))
-      )
+      new_playlist[["playlist_year_weight"]] <- playlist_weights
+    } else {
+      new_playlist <- c(new_playlist, playlist_weights)
     }
-    new_playlist <- c(list(playlist_reset = FALSE), new_playlist)
+    
+    new_playlist <- c(list("playlist_reset" = FALSE), new_playlist)
+    
     if (api_study) {
       # To minimize the number of queries, we reduce the list to the updated items
       generaldata <- generaldata[which(names(generaldata) == "general")]
@@ -252,18 +237,16 @@ setPlaylist <- function(playlist,
     generaldata$playlist <- new_playlist
   }
   
-  # write updated file
   writeIni(listData = generaldata, pathIni = "settings/generaldata", overwrite = TRUE, opts = opts)
   
-  # Update simulation options object
-  if(api_study){
+  if (api_study) {
     suppressWarnings(
       res <- antaresRead::setSimulationPathAPI(host = opts$host,
                                                study_id = opts$study_id, 
                                                token = opts$token, 
                                                simulation = "input")
     )
-  }else{
+  } else {
     suppressWarnings(
       res <- antaresRead::setSimulationPath(path = opts$studyPath, 
                                             simulation = "input")
@@ -272,3 +255,30 @@ setPlaylist <- function(playlist,
   
   return(invisible(res))
 }
+
+
+#' Generate playlist_year_weight section in the appropriate format.
+#' 
+#' @param weights
+#'   data.table, 2 columns : mcYears and weights. Only with after antares V8
+#' @param api_mode Boolean to identify an api study
+#'
+#' @return The playlist_year_weight section formatted.
+#'
+.format_playlist_weights <- function(weights, api_mode) {
+  
+  playlist_year_weight <- NULL 
+  
+  if (!is.null(weights)) {
+    if (api_mode) {
+      playlist_year_weight <- paste0(weights$mcYears - 1, ",", weights$weights)
+      playlist_year_weight <- paste("\'", playlist_year_weight, "\'", collapse  = ",", sep = "")
+      playlist_year_weight <- paste("[", playlist_year_weight, "]", sep = "")
+    } else {
+      playlist_year_weight <- paste0(weights$mcYears - 1, ",", format(round(weights$weights, 6), nsmall = 6))
+      playlist_year_weight <- setNames(playlist_year_weight, rep("playlist_year_weight", length(playlist_year_weight)))
+    }
+  }
+  
+  return(playlist_year_weight)
+}
